summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorErich Eckner <git@eckner.net>2020-01-09 00:10:22 +0100
committerErich Eckner <git@eckner.net>2021-02-14 14:55:32 +0100
commit3cfd593b1510f80bee564c2409cf0159e5abde3f (patch)
tree225f8b65d5a47efc8c428fd9ecfc274a2ff991c4
parent5cb279e54d3504fb9f4af223c51adc0d121cc834 (diff)
downloadarchiso32-3cfd593b1510f80bee564c2409cf0159e5abde3f.tar.xz
configs/releng/build.sh: pin architecture in per-arch pacman.confs
-rwxr-xr-xconfigs/releng/build.sh10
1 files changed, 9 insertions, 1 deletions
diff --git a/configs/releng/build.sh b/configs/releng/build.sh
index 742a79d..15b8780 100755
--- a/configs/releng/build.sh
+++ b/configs/releng/build.sh
@@ -52,7 +52,7 @@ run_once() {
fi
}
# Setup custom pacman.conf with current cache directories and custom mirrorlist.
make_pacman_conf() {
local _cache_dirs
_cache_dirs=("$(pacman -v 2>&1 | grep '^Cache Dirs:' | sed 's/Cache Dirs:\s*//g')")
@@ -62,6 +62,14 @@ make_pacman_conf() {
s@/var/cache/pacman/pkg/@/var/cache/archbuild32/@
s@Include = /etc/pacman\.d/mirrorlist$@\032@
' "${work_dir}/pacman-x86_64.conf" > "${work_dir}/pacman-i686.conf"
+ local _conf
+ for _conf in "${work_dir}/"pacman-*.conf; do
+ sed -i '
+ /^Architecture =/ s/=.*$/= '"${_conf##*/pacman-}"'/
+ T
+ s/\.conf$//
+ ' "${_conf}"
+ done
}
# Prepare working directory and copy custom airootfs files (airootfs)
@@ -52,7 +52,7 @@ run_once() {
fi
}
-# Setup custom pacman.conf with current cache directories and custom mirrorlist.
+# Setup custom pacman.conf with current cache directories and custom mirrorlist and custom architecture.
make_pacman_conf() {
local _cache_dirs